==> cdk_2.7.1.orig.tar.gz: cdk-cdk-2.7.1/tool/group/src/main/java/org/openscience/cdk/group/IntegerInvariant.java <==
/* Copyright (C) 2017  Gilleain Torrance <gilleain.torrance@gmail.com>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.group;

/**
 * @author maclean
 * @cdk.module group
 */
class IntegerInvariant implements Invariant {
    
    private Integer value;
    
    public IntegerInvariant(Integer value) {
        this.value = value;
    }

    @Override
    public int compareTo(Invariant o) {
        return value.compareTo(((IntegerInvariant)o).value);
    }
    
    public int hashCode() {
        return value;
    }
    
    public boolean equals(Object other) {
        return other instanceof IntegerInvariant && 
                value.equals(((IntegerInvariant)other).value);
    }
    
    public String toString() {
        return value.toString();
    }
    
}

==> cdk_2.11.orig.tar.gz: cdk-cdk-2.11/tool/group/src/main/java/org/openscience/cdk/group/IntegerInvariant.java <==
/* Copyright (C) 2017  Gilleain Torrance <gilleain.torrance@gmail.com>
 *
 * Contact: cdk-devel@lists.sourceforge.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 * All we ask is that proper credit is given for our work, which includes
 * - but is not limited to - adding the above copyright notice to the beginning
 * of your source code files, and to any copyright notice that you may distribute
 * with programs based on this work.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */
package org.openscience.cdk.group;

/**
 * @author maclean
 */
class IntegerInvariant implements Invariant {
    
    private final Integer value;
    
    public IntegerInvariant(Integer value) {
        this.value = value;
    }

    @Override
    public int compareTo(Invariant o) {
        return value.compareTo(((IntegerInvariant)o).value);
    }
    
    public int hashCode() {
        return value;
    }
    
    public boolean equals(Object other) {
        return other instanceof IntegerInvariant && 
                value.equals(((IntegerInvariant)other).value);
    }
    
    public String toString() {
        return value.toString();
    }
    
}
